@@ -533,3 +533,15 @@ class VariableClInstallDpi(Variable):
         except ValueError:
             pass
         return "96"
+
+class VariableClInstallScaling(Variable):
+    def get(self):
+        dpi = self.Get('cl_install_dpi')
+        try:
+            if dpi:
+                dpi = int(dpi)
+                if dpi > 100:
+                    return "hi"
+        except ValueError:
+            pass
+        return "normal"
